# Tutorials

The tutorials use data that can be downloaded [here](https://drive.google.com/drive/folders/1dUBC1EbUgEH-Cug-oWIS7Yy_tpAqhe4j?usp=sharing).

* {doc}`notebooks/t_siminddata`
* {doc}`notebooks/t_dicomdata`
* {doc}`notebooks/t_fbp`
* {doc}`notebooks/t_quantitative`